@@ -58,8 +58,7 @@ mod tests {
 		
 		let other_event = state.start_parse::<usize>();
 
-		let description = "Something succeeded.".to_string();
-		state.end_event(other_event, Status::Success(description));
+		state.end_event(other_event, Status::Success);
 		
 		state.advance(1)?;
 		
