@@ -4,7 +4,7 @@ use super::*;
 #[derive(Clone, Debug, Hash, PartialEq, Eq, PartialOrd, Ord)]
 pub enum Status {
 
-	Success(String),
+	Success,
 	Warning(String),
 	Error(String),
 	Note(String),
@@ -13,10 +13,10 @@ pub enum Status {
 
 impl Status {
 
-	/// Whether `self` is `Self::Success(_)`.
+	/// Whether `self` is `Self::Success`.
 	pub fn is_success (&self) -> bool {
 		
-		matches!(self, Self::Success(_))
+		matches!(self, Self::Success)
 		
 	}
 	
@@ -48,7 +48,7 @@ impl Status {
 			Self::Warning(_) => Color::Yellow,
 			Self::Error(_) => Color::Red,
 			Self::Note(_) => Color::Blue,
-			Self::Success(_) => Color::Green,
+			Self::Success => Color::Green,
 
 		}
 
@@ -61,7 +61,7 @@ impl Status {
 			Self::Warning(description) => &description,
 			Self::Error(description) => &description,
 			Self::Note(description) => &description,
-			Self::Success(description) => &description,
+			Self::Success => "",
 
 		}
 
